google-ldap3 is developed based on the original DAP3, removes the problems related to the time stamp obtained by google, and merges and packages it to generate.

If there is a problem with LDAP3 during use, please consult the original ldap3 team
LDAP3 address: https://github.com/cannatag/ldap3.git